<?php

/*
Plugin Name: Simple Posts Export To HTML
Plugin URI: https://becoming.julia-kalder.de/downloads/
Description: Description: Export existing posts including header image into one single HTML file in UTF-8
Version: 1.3
Author: Julia Kalder
Author URI: https://becoming.julia-kalder.de/
*/

// Hook for adding admin menus
add_action('admin_menu', 'export_posts_menu');

// Action function for adding menu items
function export_posts_menu() {
    add_options_page('Export Posts', 'Export Posts', 'manage_options', 'export-posts', 'export_posts_options_page');
}

// Display the admin options page
function export_posts_options_page() {
    if (!current_user_can('manage_options'))  {
        wp_die( __('You do not have sufficient permissions to access this page.') );
    }

    // Create the form
    $form = '<div class="wrap">';
    $form .= '<h2>Export Posts</h2>';
    $form .= '<form action="admin-post.php" method="post">';
    $form .= '<input type="hidden" name="action" value="export_posts_request" />';
    $form .= '<table class="form-table">';
    $form .= '<tr>';
    $form .= '<th><label for="export_posts_tags">Select tags to export:</label></th>';
    $form .= '<td>';
    $form .= '<select name="export_posts_tags[]" multiple="multiple" size="10">';
    $tags = get_tags();
    foreach ($tags as $tag) {
        $form .= '<option value="' . $tag->term_id . '">' . $tag->name . '</option>';
    }
    $form .= '</select>';
    $form .= '</td>';
    $form .= '</tr>';
    $form .= '</table>';
    $form .= '<input type="submit" name="submit" value="Export Posts" class="button-primary" />';
    $form .= '</form>';
    $form .= '</div>';

    echo $form;
}

// Hook for handling the export posts request
add_action('admin_post_export_posts_request', 'export_posts_request_handler');

// The callback function that will be triggered when the export posts request is received
function export_posts_request_handler(){
    if (!current_user_can('manage_options'))  {
        wp_die( __('You do not have sufficient permissions to access this page.') );
    }

    if (isset($_POST['export_posts_tags'])) {
        $tags = $_POST['export_posts_tags'];
        $posts = get_posts(array('tag__in' => $tags, 'posts_per_page' => -1 ));

        $output = '<html><head><meta charset="UTF-8" /></head><body>';
        foreach ($posts as $post) {
            $output .= '<h2>' . $post->post_title . '</h2>';
            $output .= '<p>Published on: ' . $post->post_date . '<br />';
            $output .= 'Category: ' . get_the_category_list(', ', '', $post->ID) . '<br />';
            $output .= 'Tags: ' . get_the_tag_list('', ', ', '', $post->ID) . '</p>';
            $output .= '<p><img src="' . get_the_post_thumbnail_url($post->ID, 'full') . '" /></p>';
            $output .= apply_filters('the_content', $post->post_content);
        }
        $output .= '</body></html>';

        $filename = 'export_posts.html';

        header('Content-Type: application/octet-stream');
        header("Content-Transfer-Encoding: Binary"); 
        header("Content-disposition: attachment; filename=\"" . basename($filename) . "\""); 
        echo $output;
        exit;
    }
}

?>